@@ -2,7 +2,6 @@ import os, subprocess, requests
 from time import sleep
 from selenium import webdriver
 from selenium.webdriver.common.by import By
-import undetected_chromedriver as uc
 
 class setup_shortcuts:
     '''Shortcut functions for Selenium'''
@@ -32,10 +31,11 @@ class setup_shortcuts:
                     sleep(1)
                     break
         
-        options = uc.ChromeOptions()
+        options = webdriver.ChromeOptions()
         options.debugger_address = f'127.0.0.1:{port}' # Must be 127.0.0.1 for undetected-chromedriver, not localhost
         if browser == 'uc':
-            driver = uc.Chrome(options=options)
+            import undetected_chromedriver as uc
+            driver = uc.Chrome(options=options, use_subprocess=True)
             os.kill(driver.browser_pid, 15) # undetected-chromedriver connects to the existing browser then starts a browser on a random port, this closes the random browser
         else:
             driver = webdriver.Chrome(options=options)
